==> phplist-2.10.5p0.tgz: lists/admin/lan/fr/users.php <==
<?php

$lan = array(
'Delete will delete user and all listmemberships' => 'Si vous cliquez sur Supprimer, vous supprimez l&rsquo;utilisateur et vous le supprimez de toutes les listes',
'%s users apply' => '%s utilisateurs correspondent',
'Users marked <font color=red>red</font> are unconfirmed' => 'Les utilisateurs marqu&eacute;s en <font color=red>rouge</font> n&rsquo;ont pas confirm&eacute; leur inscription',
'Show only unconfirmed users' => 'Utilisateurs non confirm&eacute;s',
'Show only blacklisted users' => 'Utilisateurs sur liste noire',
'email' => 'email',
'bouncecount' => 'messages rejet&eacute;s',
'entered' => 'inscription',
'modified' => 'modification',
'foreignkey' => 'foreignkey',
'Sort by' => 'Trier par',
'desc' => 'desc',
'asc' => 'asc',
'Go' => 'Trier',
'Find a user' => 'Trouver un utilisateur',
'Email' => 'Email',
'Foreign Key' => 'Foreign Key',
'reset' => 'remettre &agrave; z&eacute;ro',
'Download all users as CSV file' => 'T&eacute;l&eacute;charger tous les utilisateurs vers un fichier CSV',
'Add a User' => 'Ajouter un Utilisateur',
'confirmed' => 'confirm&eacute;',
'bl l' => 'liste nr', # as in black listed (but then as short as possible)
'del' => 'suppr',
'key' => 'cl&eacute;',
'msgs' => 'msgs', # meaning messages
'rss' => 'rss',
'rss freq' => 'fr&eacute;q rss', # meaning rss frequency
'bncs' => 'rejets', # meaning bounces
'No users apply' => 'Aucun utilisateur ne correspond',
'Your privileges for this page are insufficient' => 'Pour n&rsquo;&ecirc;tes pas autoris&eacute;(e) &agrave; faire cela',
'Delete will delete user from the list' => 'Si vous cliquez sur Supprimer, vous supprimez cet utilisateur de cette liste',
'deleting' => 'suppression',
'Done' => 'C&rsquo;est fait',
'User added' => 'Utilisateur ajout&eacute;',
'Add this user' => 'Ajouter cet utilisateur',
'Click on a link to use the corresponding public subscribe page to add this user:' => 'Cliquer sur un lien pour utiliser la page publique d&rsquo;inscription pour ajouter cet utilisateur:',
'Click this link to use the public subscribe page to add this user:' => 'Cliquez sur ce lien pour utiliser la page publique d&rsquo;inscription pour ajouter cet utilisateur:',
'Listing user %d to %d' => 'Liste des utilisateurs %d &agrave; %d',
'last sent' => 'dernier envoi',


);

?>

==> phplist-2.10.18.tgz: lists/admin/lan/fr/users.php <==
<?php

$lan = array(
'Delete will delete user and all listmemberships' => 'Si vous cliquez sur Supprimer, vous supprimez l&rsquo;utilisateur et vous le supprimez de toutes les listes',
'%s users apply' => '%s utilisateurs correspondent',
'Users marked <span class="highlight">red</span> are unconfirmed' => 'Les utilisateurs marqu&eacute;s en <span class="highlight">rouge</span> n&rsquo;ont pas confirm&eacute; leur inscription',
'Show only unconfirmed users' => 'Utilisateurs non confirm&eacute;s',
'Show only blacklisted users' => 'Utilisateurs sur liste noire',
'email' => 'email',
'bouncecount' => 'messages rejet&eacute;s',
'entered' => 'inscription',
'modified' => 'modification',
'foreignkey' => 'foreignkey',
'Sort by' => 'Trier par',
'desc' => 'desc',
'asc' => 'asc',
'Go' => 'Trier',
'Find a user' => 'Trouver un utilisateur',
'Email' => 'Email',
'Foreign Key' => 'Foreign Key',
'reset' => 'remettre &agrave; z&eacute;ro',
'Download all users as CSV file' => 'T&eacute;l&eacute;charger tous les utilisateurs vers un fichier CSV',
'Add a User' => 'Ajouter un Utilisateur',
'confirmed' => 'confirm&eacute;',
'bl l' => 'liste nr', # as in black listed (but then as short as possible)
'del' => 'suppr',
'key' => 'cl&eacute;',
'msgs' => 'msgs', # meaning messages
'rss' => 'rss',
'rss freq' => 'fr&eacute;q rss', # meaning rss frequency
'bncs' => 'rejets', # meaning bounces
'No users apply' => 'Aucun utilisateur ne correspond',
'Your privileges for this page are insufficient' => 'Pour n&rsquo;&ecirc;tes pas autoris&eacute;(e) &agrave; faire cela',
'Delete will delete user from the list' => 'Si vous cliquez sur Supprimer, vous supprimez cet utilisateur de cette liste',
'deleting' => 'suppression',
'Done' => 'C&rsquo;est fait',
'User added' => 'Utilisateur ajout&eacute;',
'Add this user' => 'Ajouter cet utilisateur',
'Click on a link to use the corresponding public subscribe page to add this user:' => 'Cliquer sur un lien pour utiliser la page publique d&rsquo;inscription pour ajouter cet utilisateur:',
'Click this link to use the public subscribe page to add this user:' => 'Cliquez sur ce lien pour utiliser la page publique d&rsquo;inscription pour ajouter cet utilisateur:',
'Listing user %d to %d' => 'Liste des utilisateurs %d &agrave; %d',
'last sent' => 'dernier envoi',


);

?>
